@@ -111,7 +111,8 @@ if not PYDANTIC_V1:
     ) -> dict[str, Any]:
         """Get possibly nested default values for a Model object."""
         dflt = {}
-        for k, v in obj.model_fields.items():
+        cls = obj if isinstance(obj, type) else type(obj)
+        for k, v in cls.model_fields.items():
             d = v.get_default()
             if (
                 d is None
@@ -125,7 +126,9 @@ if not PYDANTIC_V1:
     def _get_config(cls: pydantic.BaseModel) -> "ConfigDict":
         return cls.model_config
 
-    def _get_fields(cls: pydantic.BaseModel) -> dict[str, pydantic.fields.FieldInfo]:
+    def _get_fields(
+        cls: type[pydantic.BaseModel],
+    ) -> dict[str, pydantic.fields.FieldInfo]:
         return cls.model_fields
 
     def _model_dump(obj: pydantic.BaseModel) -> dict:
@@ -384,7 +387,7 @@ class EventedModel(pydantic.BaseModel, metaclass=EventedMetaclass):
     (see [pydantic docs](https://pydantic-docs.helpmanual.io/usage/models/)),
     this class adds the following:
 
-    1. gains an `events` attribute that is an instance of [`psygnal.SignalGroup`][].
+    1. Gains an `events` attribute that is an instance of [`psygnal.SignalGroup`][].
        This group will have a signal for each field in the model (excluding private
        attributes and non-mutable fields).  Whenever a field in the model is mutated,
        the corresponding signal will emit with the new value (see example below).
@@ -404,14 +407,16 @@ class EventedModel(pydantic.BaseModel, metaclass=EventedMetaclass):
           dependencies by inspecting the source code of the property getter for.
 
     4. If you would like to allow custom fields to provide their own json_encoders, you
-       can either use the standard pydantic method of adding json_encoders to your
-       model, for each field type you'd like to support:
-       https://pydantic-docs.helpmanual.io/usage/exporting_models/#json_encoders
-       This `EventedModel` class will additionally look for a `_json_encode` method
-       on any field types in the model.  If a field type declares a `_json_encode`
-       method, it will be added to the
-       [`json_encoders`](https://pydantic-docs.helpmanual.io/usage/exporting_models/#json_encoders)
-       dict in the model `Config`.
+       can either:
+
+        1. use the [standard pydantic
+        method](https://pydantic-docs.helpmanual.io/usage/exporting_models) of adding
+        json_encoders to your model, for each field type you'd like to support: 1. This
+        `EventedModel` class will additionally look for a `_json_encode` method on any
+        field types in the model.  If a field type declares a `_json_encode` method, it
+        will be added to the
+        [`json_encoders`](https://pydantic-docs.helpmanual.io/usage/exporting_models/#json_encoders)
+        dict in the model `Config`.  (Prefer using the standard pydantic method)
 
     Examples
     --------
@@ -547,7 +552,7 @@ class EventedModel(pydantic.BaseModel, metaclass=EventedMetaclass):
     def reset(self) -> None:
         """Reset the state of the model to default values."""
         model_config = _get_config(self)
-        model_fields = _get_fields(self)
+        model_fields = _get_fields(type(self))
         for name, value in self._defaults.items():
             if isinstance(value, EventedModel):
                 cast("EventedModel", getattr(self, name)).reset()
@@ -710,6 +715,6 @@ class EventedModel(pydantic.BaseModel, metaclass=EventedMetaclass):
                 yield
             finally:
                 if before is not NULL:  # pragma: no cover
-                    cls.model_config["use_enum_values"] = cast(bool, before)
+                    cls.model_config["use_enum_values"] = cast("bool", before)
                 else:
                     cls.model_config.pop("use_enum_values")
