@@ -128,26 +128,21 @@ connection type (in that case, depending on threading).
 from __future__ import annotations
 
 import inspect
-import sys
 import threading
 import warnings
 import weakref
 from collections import deque
-from contextlib import contextmanager, suppress
-from functools import lru_cache, partial, reduce
+from contextlib import AbstractContextManager, contextmanager, suppress
+from functools import cache, partial, reduce
 from inspect import Parameter, Signature, isclass
 from typing import (
     TYPE_CHECKING,
     Any,
     Callable,
     ClassVar,
-    ContextManager,
     Final,
-    Iterable,
-    Iterator,
     Literal,
     NoReturn,
-    Type,
     TypeVar,
     Union,
     cast,
@@ -169,6 +164,8 @@ from ._weak_callback import (
 )
 
 if TYPE_CHECKING:
+    from collections.abc import Container, Iterable, Iterator
+
     from ._group import EmissionInfo
     from ._weak_callback import RefErrorChoice
 
@@ -184,7 +181,14 @@ __all__ = ["Signal", "SignalInstance", "_compiled"]
 
 _NULL = object()
 F = TypeVar("F", bound=Callable)
-RECURSION_LIMIT = sys.getrecursionlimit()
+
+# using 300 instead of sys.getrecursionlimit()
+# in a mypyc-compiled program, hitting an actual RecursionError can cause
+# a segfault (rather than raise a python exception), so we really MUST
+# avoid it.  Windows has a lower stack limit than other platforms, so we
+# use 300 as a cross-platform "safe" limit, determined via testing.  It's
+# probably plenty large for most reasonable use-cases.
+RECURSION_LIMIT = 300
 
 ReemissionVal = Literal["immediate", "queued", "latest-only"]
 VALID_REEMISSION = set(ReemissionVal.__args__)  # type: ignore
@@ -314,7 +318,7 @@ class Signal:
                     stacklevel=2,
                 )
         else:
-            self._signature = _build_signature(*cast("tuple[Type[Any], ...]", types))
+            self._signature = _build_signature(*cast("tuple[type[Any], ...]", types))
 
     @property
     def signature(self) -> Signature:
@@ -395,6 +399,7 @@ class Signal:
             self.signature,
             instance=instance,
             name=name or self._name,
+            description=self.description,
             check_nargs_on_connect=self._check_nargs_on_connect,
             check_types_on_connect=self._check_types_on_connect,
             reemission=self._reemission,
@@ -491,6 +496,19 @@ class SignalInstance:
     reemission : Literal["immediate", "queued", "latest-only"] | None
         See docstring for [`Signal`][psygnal.Signal] for details.
         By default, `"immediate"`.
+    description : str
+        Optional descriptive text for the signal.  (not used internally).
+
+    Attributes
+    ----------
+    signature : Signature
+        Signature supported by this `SignalInstance`.
+    instance : Any
+        Object that emits this `SignalInstance`.
+    name : str
+        Name of this `SignalInstance`.
+    description : str
+        Description of this `SignalInstance`.
 
     Raises
     ------
@@ -509,6 +527,7 @@ class SignalInstance:
         *,
         instance: Any = None,
         name: str | None = None,
+        description: str = "",
         check_nargs_on_connect: bool = True,
         check_types_on_connect: bool = False,
         reemission: ReemissionVal = DEFAULT_REEMISSION,
@@ -521,6 +540,7 @@ class SignalInstance:
                 "instance of `inspect.Signature`"
             )
 
+        self._description = description
         self._reemission = ReemissionMode.validate(reemission)
         self._name = name
         self._instance: Callable = self._instance_ref(instance)
@@ -572,6 +592,11 @@ class SignalInstance:
         """Name of this `SignalInstance`."""
         return self._name or ""
 
+    @property
+    def description(self) -> str:
+        """Description of this `SignalInstance`."""
+        return self._description
+
     def __repr__(self) -> str:
         """Return repr."""
         name = f" {self._name!r}" if self._name else ""
@@ -1038,8 +1063,8 @@ class SignalInstance:
             slot_sig = _get_signature_possibly_qt(slot)
         except ValueError as e:
             warnings.warn(
-                f"{e}. To silence this warning, connect with " "`check_nargs=False`",
-                stacklevel=2,
+                f"{e}. To silence this warning, connect with `check_nargs=False`",
+                stacklevel=4,
             )
             return None, None, False
         try:
@@ -1175,6 +1200,61 @@ class SignalInstance:
 
         self._run_emit_loop(args)
 
+    def emit_fast(self, *args: Any) -> None:
+        """Fast emit without any checks.
+
+        This method can be up to 10x faster than `emit()`, but it lacks most of the
+        features and safety checks of `emit()`. Use with caution.  Specifically:
+
+        - It does not support `check_nargs` or `check_types`
+        - It does not use any thread safety locks.
+        - It is not possible to query the emitter with `Signal.current_emitter()`
+        - It is not possible to query the sender with `Signal.sender()`
+        - It does not support "queued" or "latest-only" reemission modes for nested
+          emits. It will always use "immediate" mode, wherein signals emitted by
+          callbacks are immediately processed in a deeper emission loop.
+
+        It DOES, however, support `paused()` and `blocked()`
+
+        Parameters
+        ----------
+        *args : Any
+            These arguments will be passed when calling each slot (unless the slot
+            accepts fewer arguments, in which case extra args will be discarded.)
+        """
+        if self._is_blocked:
+            return
+
+        if self._is_paused:
+            self._args_queue.append(args)
+            return
+
+        if self._recursion_depth >= RECURSION_LIMIT:
+            raise RecursionError(
+                f"Psygnal recursion limit ({RECURSION_LIMIT}) reached when emitting "
+                f"signal {self.name!r} with args {args}"
+            )
+
+        self._recursion_depth += 1
+        try:
+            for caller in self._slots:
+                caller.cb(args)
+        except RecursionError as e:
+            raise RecursionError(
+                f"RecursionError when emitting signal {self.name!r} with args {args}"
+            ) from e
+        except EmitLoopError as e:  # pragma: no cover
+            raise e
+        except Exception as cb_err:
+            loop_err = EmitLoopError(exc=cb_err, signal=self).with_traceback(
+                cb_err.__traceback__
+            )
+            # this comment will show up in the traceback
+            raise loop_err from cb_err  # emit() call ABOVE || callback error BELOW
+        finally:
+            if self._recursion_depth > 0:
+                self._recursion_depth -= 1
+
     def __call__(
         self, *args: Any, check_nargs: bool = False, check_types: bool = False
     ) -> None:
@@ -1182,6 +1262,9 @@ class SignalInstance:
         return self.emit(*args, check_nargs=check_nargs, check_types=check_types)
 
     def _run_emit_loop(self, args: tuple[Any, ...]) -> None:
+        if self._recursion_depth >= RECURSION_LIMIT:
+            raise RecursionError("Recursion limit reached!")
+
         with self._lock:
             self._emit_queue.append(args)
             if len(self._emit_queue) > 1:
@@ -1199,9 +1282,9 @@ class SignalInstance:
                     f"RecursionError when "
                     f"emitting signal {self.name!r} with args {args}"
                 ) from e
+            except EmitLoopError as e:
+                raise e
             except Exception as cb_err:
-                if isinstance(cb_err, EmitLoopError):
-                    raise cb_err
                 loop_err = EmitLoopError(
                     exc=cb_err,
                     signal=self,
@@ -1244,7 +1327,7 @@ class SignalInstance:
                     raise RecursionError
             i += 1
 
-    def block(self, exclude: Iterable[str | SignalInstance] = ()) -> None:
+    def block(self, exclude: Container[str | SignalInstance] = ()) -> None:
         """Block this signal from emitting.
 
         NOTE: the `exclude` argument is only for SignalGroup subclass, but we
@@ -1256,7 +1339,7 @@ class SignalInstance:
         """Unblock this signal, allowing it to emit."""
         self._is_blocked = False
 
-    def blocked(self) -> ContextManager[None]:
+    def blocked(self) -> AbstractContextManager[None]:
         """Context manager to temporarily block this signal.
 
         Useful if you need to temporarily block all emission of a given signal,
@@ -1347,7 +1430,7 @@ class SignalInstance:
 
     def paused(
         self, reducer: ReducerFunc | None = None, initial: Any = _NULL
-    ) -> ContextManager[None]:
+    ) -> AbstractContextManager[None]:
         """Context manager to temporarily pause this signal.
 
         Parameters
@@ -1428,7 +1511,7 @@ class _SignalBlocker:
     """Context manager to block and unblock a signal."""
 
     def __init__(
-        self, signal: SignalInstance, exclude: Iterable[str | SignalInstance] = ()
+        self, signal: SignalInstance, exclude: Container[str | SignalInstance] = ()
     ) -> None:
         self._signal = signal
         self._exclude = exclude
@@ -1483,7 +1566,7 @@ _ANYSIG = Signature(
 )
 
 
-@lru_cache(maxsize=None)
+@cache
 def _stub_sig(obj: Any) -> Signature:
     """Called as a backup when inspect.signature fails."""
     import builtins
