@@ -1,7 +1,8 @@
 import inspect
 import sys
+from collections.abc import Sequence
 from contextlib import nullcontext
-from typing import Any, ClassVar, List, Protocol, Sequence, Union, runtime_checkable
+from typing import Any, ClassVar, Protocol, Union, runtime_checkable
 from unittest.mock import Mock, call, patch
 
 import numpy as np
@@ -422,7 +423,7 @@ class T(EventedModel):
     b: int = 1
 
     @property
-    def c(self) -> List[int]:
+    def c(self) -> list[int]:
         return [self.a, self.b]
 
     @c.setter
@@ -485,7 +486,7 @@ def test_properties_with_explicit_property_dependencies():
         b: int = 1
 
         @property
-        def c(self) -> List[int]:
+        def c(self) -> list[int]:
             return [self.a, self.b]
 
         @c.setter
@@ -913,10 +914,10 @@ def test_if_event_is_emitted_only_once() -> None:
     ],
 )
 def test_evented_model_reemission(mode: Union[str, dict]) -> None:
-    err = mode == "err" or isinstance(mode, dict) and "err" in mode.values()
-    with pytest.raises(
-        ValueError, match="Invalid reemission"
-    ) if err else nullcontext():
+    err = mode == "err" or (isinstance(mode, dict) and "err" in mode.values())
+    with (
+        pytest.raises(ValueError, match="Invalid reemission") if err else nullcontext()
+    ):
 
         class Model(EventedModel):
             a: int
@@ -939,3 +940,46 @@ def test_evented_model_reemission(mode: Union[str, dict]) -> None:
     else:
         assert m.events.a._reemission == mode
         assert m.events.b._reemission == mode
+
+
+@pytest.mark.skipif(not PYDANTIC_V2, reason="computed_field added in v2")
+def test_computed_field() -> None:
+    from pydantic import computed_field
+
+    class MyModel(EventedModel):
+        a: int = 1
+        b: int = 1
+
+        @computed_field
+        @property
+        def c(self) -> list[int]:
+            return [self.a, self.b]
+
+        @c.setter
+        def c(self, val: Sequence[int]) -> None:
+            self.a, self.b = val
+
+        model_config = {
+            "allow_property_setters": True,
+            "field_dependencies": {"c": ["a", "b"]},
+        }
+
+    mock_a = Mock()
+    mock_b = Mock()
+    mock_c = Mock()
+    m = MyModel()
+    m.events.a.connect(mock_a)
+    m.events.b.connect(mock_b)
+    m.events.c.connect(mock_c)
+
+    m.c = [10, 20]
+    mock_a.assert_called_with(10)
+    mock_b.assert_called_with(20)
+    mock_c.assert_called_with([10, 20])
+
+    mock_a.reset_mock()
+    mock_c.reset_mock()
+
+    m.a = 5
+    mock_a.assert_called_with(5)
+    mock_c.assert_called_with([5, 20])
